@@ -1,5 +1,6 @@
 from .base import AbstractBaseNode
-from solid2 import union
+from solid2 import union, get_animation_time
+
 
 class InternalNode(AbstractBaseNode):
 
@@ -37,19 +38,3 @@ class InternalNode(AbstractBaseNode):
             if type(child) is type(self):
                 raise Exception(f"{self.__class__}.render() cannot return its "
                                 "own type")
-
-
-class FusionNode(InternalNode):
-
-    @property
-    def time(self):
-        raise Exception(f"FusionNode cannot rely on time, use AssemblyNode for animation")
-
-
-class AssemblyNode(InternalNode):
-
-    @property
-    def time(self):
-        """The $t variable, the animation time from 0 to 1"""
-        self.rigid = False
-        return get_animation_time()
